==> apache-seatunnel-2.3.9-src.tar.gz: apache-seatunnel-2.3.9-src/seatunnel-connectors-v2/connector-jdbc/src/test/java/org/apache/seatunnel/connectors/seatunnel/jdbc/internal/dialect/JdbcDialectLoaderTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect;

import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.mysql.MysqlDialect;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

/** Test for {@link JdbcDialectLoader} */
public class JdbcDialectLoaderTest {
    @Test
    public void shouldFindGenericDialect() throws Exception {
        JdbcDialect jdbcDialect = JdbcDialectLoader.load("jdbc:someting:", "");
        Assertions.assertTrue(jdbcDialect instanceof GenericDialect);
    }

    @Test
    public void shouldFindMysqlDialect() throws Exception {
        JdbcDialect jdbcDialect = JdbcDialectLoader.load("jdbc:mysql://localhost:3306/test", "");
        Assertions.assertTrue(jdbcDialect instanceof MysqlDialect);
    }
}

==> apache-seatunnel-2.3.11-src.tar.gz: apache-seatunnel-2.3.11-src/seatunnel-connectors-v2/connector-jdbc/src/test/java/org/apache/seatunnel/connectors/seatunnel/jdbc/internal/dialect/JdbcDialectLoaderTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect;

import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.mysql.MysqlDialect;
import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.psql.PostgresDialect;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

/** Test for {@link JdbcDialectLoader} */
public class JdbcDialectLoaderTest {
    @Test
    public void shouldFindGenericDialect() throws Exception {
        JdbcDialect jdbcDialect = JdbcDialectLoader.load("jdbc:someting:", null, "");
        Assertions.assertInstanceOf(GenericDialect.class, jdbcDialect);
    }

    @Test
    public void shouldFindMysqlDialect() throws Exception {
        JdbcDialect jdbcDialect =
                JdbcDialectLoader.load("jdbc:mysql://localhost:3306/test", null, "");
        Assertions.assertInstanceOf(MysqlDialect.class, jdbcDialect);
    }

    /** Test for {@link JdbcDialectLoader} for appointDialect */
    @Test
    public void shouldFindPostgresSQLDialectByDialect() throws Exception {
        JdbcDialect jdbcDialect =
                JdbcDialectLoader.load("error:errorurl://xxxxx:3306/test", "Postgres", "");
        Assertions.assertInstanceOf(PostgresDialect.class, jdbcDialect);
    }
}
